@@ -1,4 +1,4 @@
-#' Confidence/Credible Interval
+#' Confidence/Credible Interval (CI)
 #'
 #' Compute Confidence/Credible Intervals (CI) for Bayesian (using quantiles) and frequentist models.
 #'
@@ -57,6 +57,8 @@
 #' ci(model)
 #' ci(model, ci = c(.80, .89, .95))
 #'
+#' library(emmeans)
+#' ci(emtrends(model, ~1, "wt"))
 #' \dontrun{
 #' library(brms)
 #' model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
@@ -82,7 +84,7 @@ ci.numeric <- function(x, ci = .89, verbose = TRUE, ...) {
   out <- do.call(rbind, lapply(ci, function(i) {
     .credible_interval(x = x, ci = i, verbose = verbose)
   }))
-  class(out) <- unique(c("ci", "see_ci", class(out)))
+  class(out) <- unique(c("bayestestR_ci", "see_ci", class(out)))
   attr(out, "data") <- x
   out
 }
@@ -97,6 +99,19 @@ ci.data.frame <- function(x, ci = .89, verbose = TRUE, ...) {
   dat
 }
 
+#' @rdname ci
+#' @export
+ci.emmGrid <- function(x, ci = .89, verbose = TRUE, ...) {
+  if (!requireNamespace("emmeans")) {
+    stop("Package \"emmeans\" needed for this function to work. Please install it.")
+  }
+  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+
+  dat <- .compute_interval_dataframe(x = xdf, ci = ci, verbose = verbose, fun = "ci")
+  attr(dat, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  dat
+}
+
 
 #' @rdname ci
 #' @export
