@@ -54,6 +54,8 @@
 #' hdi(model)
 #' hdi(model, ci = c(.80, .90, .95))
 #'
+#' library(emmeans)
+#' hdi(emtrends(model, ~1, "wt"))
 #' \dontrun{
 #' library(brms)
 #' model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
@@ -101,6 +103,18 @@ hdi.data.frame <- function(x, ci = .89, verbose = TRUE, ...) {
   dat
 }
 
+#' @rdname hdi
+#' @export
+hdi.emmGrid <- function(x, ci = .89, verbose = TRUE, ...) {
+  if (!requireNamespace("emmeans")) {
+    stop("Package \"emmeans\" needed for this function to work. Please install it.")
+  }
+  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+  out <- hdi(xdf, ci = ci, verbose = verbose, ...)
+  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  out
+}
+
 
 
 #' @importFrom insight get_parameters
