@@ -17,6 +17,8 @@
 #' model <- stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200)
 #' p_map(model)
 #'
+#' library(emmeans)
+#' p_map(emtrends(model, ~1, "wt"))
 #' \dontrun{
 #' library(brms)
 #' model <- brms::brm(mpg ~ wt + cyl, data = mtcars)
@@ -78,13 +80,22 @@ p_map.data.frame <- function(x, precision = 2^10, ...) {
   out
 }
 
+#' @export
+p_map.emmGrid <- function(x, precision = 2^10, ...) {
+  if (!requireNamespace("emmeans")) {
+    stop("Package \"emmeans\" needed for this function to work. Please install it.")
+  }
+  xdf <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(x, names = FALSE)))
+  out <- p_map(xdf, precision = precision, ...)
+  attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
+  out
+}
 
 
 #' @importFrom insight get_parameters
 #' @keywords internal
 .p_map_models <- function(x, precision, effects, component, parameters, ...) {
   out <- p_map(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), precision = precision, ...)
-  out$Parameter <- .get_parameter_names(x, effects = effects, component = component, parameters = parameters)
 
   out
 }
